<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>tkConstants</name>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="135"/>
        <source>English</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="138"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="139"/>
        <source>Recent files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="141"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="142"/>
        <source>Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="143"/>
        <source>List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="144"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="198"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="145"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="146"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="147"/>
        <source>Paragraph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="148"/>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="149"/>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="150"/>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="151"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="575"/>
        <source>Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="152"/>
        <source>Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="153"/>
        <source>Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="154"/>
        <source>Languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="155"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="246"/>
        <source>Interpretor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="156"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="238"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="157"/>
        <source>About databases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="158"/>
        <source>Update available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="161"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="162"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="163"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="164"/>
        <source>Save as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="165"/>
        <source>Print...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="166"/>
        <source>Print preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="167"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="168"/>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="170"/>
        <source>New Patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="171"/>
        <source>Remove Patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="172"/>
        <source>View Patient Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="173"/>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="175"/>
        <source>Open a prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="176"/>
        <source>Save a prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="177"/>
        <source>Print a prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="179"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="180"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="181"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="182"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="183"/>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="184"/>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="185"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="186"/>
        <source>Deselect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="187"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="188"/>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="189"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="190"/>
        <source>Add to list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="192"/>
        <source>Move item up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="193"/>
        <source>Move item down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="194"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="454"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="195"/>
        <source>Sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="199"/>
        <source>Create a new template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="201"/>
        <source>Add a category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="202"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="203"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="204"/>
        <source>Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="205"/>
        <source>Unlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="206"/>
        <source>Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="207"/>
        <source>Unlocked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="214"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="215"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="216"/>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="217"/>
        <source>Strike</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="218"/>
        <source>Bigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="219"/>
        <source>Smaller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="220"/>
        <source>Font format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="221"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="222"/>
        <source>Table format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="223"/>
        <source>Image format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="224"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="225"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="226"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="227"/>
        <source>Justify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="229"/>
        <source>Add table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="230"/>
        <source>Table properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="231"/>
        <source>Add row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="232"/>
        <source>Remove row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="233"/>
        <source>Add colunm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="234"/>
        <source>Remove column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="235"/>
        <source>Merge cells</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="236"/>
        <source>Split cells</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="239"/>
        <source>About Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="240"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="241"/>
        <source>About this form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="242"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="245"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="243"/>
        <source>Debugging tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="244"/>
        <source>Display/Hide form&apos;s help text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="247"/>
        <source>User manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="248"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="249"/>
        <source>Application global configurator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="250"/>
        <source>Configure MedinTux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="252"/>
        <source>Print Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="253"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="519"/>
        <source>Translators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="256"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="257"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="259"/>
        <source>Navigation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="260"/>
        <source>Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="263"/>
        <source>Drugs database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="268"/>
        <source>Interactions database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="271"/>
        <source>INN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="273"/>
        <source>intake(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="274"/>
        <source>View synthetic interactions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="275"/>
        <source>from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="276"/>
        <source>to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="278"/>
        <source>during</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="279"/>
        <source>each</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="280"/>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="288"/>
        <source>Interaction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="289"/>
        <source>Take into account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="290"/>
        <source>Discouraged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="291"/>
        <source>Contraindication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="294"/>
        <source>Precaution for use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="295"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="452"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="304"/>
        <source>Bank details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="305"/>
        <source>Available movements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="314"/>
        <source>The %1 driver is not available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="315"/>
        <source>The %1 database driver is not installed or can not be found. Please report this error to the developper.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="316"/>
        <source>Database %1: Schema error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="322"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="323"/>
        <source>second(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="324"/>
        <source>minute(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="325"/>
        <source>hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="326"/>
        <source>day(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="327"/>
        <source>week(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="328"/>
        <source>month(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="329"/>
        <source>quarter(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="409"/>
        <source>More information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="410"/>
        <source>Hide extra information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="414"/>
        <source>Connected as
  %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="331"/>
        <source>decade(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="208"/>
        <source>Templates database information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="251"/>
        <source>View update information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="264"/>
        <source>Drugs database information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="265"/>
        <source>Protocols database information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="266"/>
        <source>Interactions database information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="267"/>
        <source>Past medical history database information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="354"/>
        <source>wake up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="355"/>
        <source>breakfast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="357"/>
        <source>morning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="358"/>
        <source>midday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="359"/>
        <source>lunch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="360"/>
        <source>afternoon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="363"/>
        <source>evening</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="364"/>
        <source>bedtime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="200"/>
        <source>Toggle template view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="140"/>
        <source>Patient navigation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="191"/>
        <source>Remove from list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="196"/>
        <source>Web site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="210"/>
        <source>PMHx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="211"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="300"/>
        <source>Past medical history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="212"/>
        <source>PMHx preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="255"/>
        <source>Toggle full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="269"/>
        <source>Drugs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="270"/>
        <source>Protocols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="272"/>
        <source>ATC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="277"/>
        <source>from %1 to %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="281"/>
        <source>Allergy to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="282"/>
        <source>Intolerance to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="283"/>
        <source>No known allergies / intolerances</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="284"/>
        <source>Known allergies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="285"/>
        <source>Known intolerances</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="292"/>
        <source>Cytochrome P450 interaction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="293"/>
        <source>Glycoprotein-P interaction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="296"/>
        <source>Molecule is duplicated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="297"/>
        <source>Class is duplicated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="303"/>
        <source>Accountancy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="306"/>
        <source>Medical procedures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="307"/>
        <source>Sites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="308"/>
        <source>Insurance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="309"/>
        <source>Percentages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="310"/>
        <source>Distance rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="311"/>
        <source>Assets rates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="317"/>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="318"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="319"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="330"/>
        <source>year(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="333"/>
        <source>second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="334"/>
        <source>minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="335"/>
        <source>hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="336"/>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="337"/>
        <source>week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="338"/>
        <source>month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="339"/>
        <source>quarter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="340"/>
        <source>year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="341"/>
        <source>decade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="343"/>
        <source>seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="344"/>
        <source>minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="345"/>
        <source>hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="346"/>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="347"/>
        <source>weeks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="348"/>
        <source>months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="349"/>
        <source>quarters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="350"/>
        <source>years</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="351"/>
        <source>decades</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="356"/>
        <source>mid-morning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="361"/>
        <source>mid-afternoon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="362"/>
        <source>dinner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="367"/>
        <source>no meal relation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="368"/>
        <source>during meal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="369"/>
        <source>after meal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="370"/>
        <source>before meal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="371"/>
        <source>not during meal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="372"/>
        <source>only if meal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="373"/>
        <source>separated from food (1-2 hours)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="374"/>
        <source>suggested with food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="375"/>
        <source>with or without food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="378"/>
        <source>Using library : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="379"/>
        <source>Starting application at %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="380"/>
        <source>Initializing Translations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="381"/>
        <source>Initializing libraries...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="382"/>
        <source>Needed Licence Agreement...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="383"/>
        <source>Checking directory structure...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="384"/>
        <source>Initializing Default Parameters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="385"/>
        <source>Initializing Plugins...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="386"/>
        <source>First time running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="387"/>
        <source>This feature is not yet implemented.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="388"/>
        <source>Raising Application...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="389"/>
        <source>Check for update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="390"/>
        <source>Checking for updates...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="391"/>
        <source>Initializing databases...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="394"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="395"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="396"/>
        <source>ICD10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="397"/>
        <source>now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="398"/>
        <source>low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="399"/>
        <source>medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="400"/>
        <source>high</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="401"/>
        <source>modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="404"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="406"/>
        <source>Settings recovered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="405"/>
        <source>Reading settings file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="407"/>
        <source>Creating default settings for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="408"/>
        <source>Show details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="522"/>
        <source>Build information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="523"/>
        <source>Version information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="541"/>
        <source>Agenda database information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="588"/>
        <source>Patient information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="413"/>
        <source>Welcome to FreeMedForms, you are now connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="415"/>
        <source>No user connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="416"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="417"/>
        <source>Users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="418"/>
        <source>User datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="419"/>
        <source>Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="420"/>
        <source>User rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="421"/>
        <source>Medical rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="422"/>
        <source>Administrative rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="423"/>
        <source>User manager rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="424"/>
        <source>Drug rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="426"/>
        <source>Save and restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="429"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="430"/>
        <source>Path %1 does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="431"/>
        <source>Path %1 is not empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="432"/>
        <source>Path %1 contains dirs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="433"/>
        <source>Path %1 can not be removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="434"/>
        <source>Path %1 can not be created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="435"/>
        <source>Creating dir %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="436"/>
        <source>File %1 does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="437"/>
        <source>File %1 is not readable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="438"/>
        <source>File %1 can not be removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="439"/>
        <source>File %1 loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="440"/>
        <source>File %1 is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="442"/>
        <source>Open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="443"/>
        <source>Opening file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="444"/>
        <source>Saving file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="447"/>
        <source>Wrong number of tags (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="448"/>
        <source>Wrong root tag %1 %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="449"/>
        <source>Document type name mismatch.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="453"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="455"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="456"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="457"/>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="458"/>
        <source>Provider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="459"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="460"/>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="461"/>
        <source>Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="462"/>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="463"/>
        <source>Messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="464"/>
        <source>Logged Messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="465"/>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="466"/>
        <source>Logged Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="467"/>
        <source>Informative message : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="468"/>
        <source>Starting task : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="469"/>
        <source>posting message to : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="470"/>
        <source>Error %1 occured while %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="471"/>
        <source>Error %1 : line %2, column %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="472"/>
        <source>Can not create %1 : it already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="473"/>
        <source>Can not return %1 : it does not exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="474"/>
        <source>Can not create %1 : no parent founded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="475"/>
        <source>%1 is not avaible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="476"/>
        <source>%1 is not avaible and can not be created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="477"/>
        <source>%1 are not avaible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="478"/>
        <source>Setting %1 path to %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="479"/>
        <source>Error %1 from database %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="480"/>
        <source>No object to translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="481"/>
        <source>No %1 found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="482"/>
        <source>Please describe your problem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="483"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="484"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="485"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="486"/>
        <source>General preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="487"/>
        <source>User preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="488"/>
        <source>Fatal error : Application failure. Please restart application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="490"/>
        <source>Connected to database %1 with driver %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="491"/>
        <source>Trying to create %1 
Place : %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="492"/>
        <source>Unable to open database %1 : Error : %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="493"/>
        <source>Unable to save data in database %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="494"/>
        <source>Database %1 correctly created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="495"/>
        <source>User %1 correctly created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="496"/>
        <source>Database %1 can not be created. Error: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="499"/>
        <source>Starting to send message.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="500"/>
        <source>Message sended without error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="501"/>
        <source>An error occured, message was not sended.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="502"/>
        <source>Checking for updates from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="503"/>
        <source>Version up to date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="504"/>
        <source>Current version :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="505"/>
        <source>Lastest version :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="506"/>
        <source>Update Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="509"/>
        <source>Creator and Main Developper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="510"/>
        <source>Developpers and Contributors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="511"/>
        <source>Debugger advisor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="512"/>
        <source>Developper and debugger advisor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="513"/>
        <source>Packager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="514"/>
        <source>Packager for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="515"/>
        <source>Drugs Database Management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="516"/>
        <source>Medical advisors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="517"/>
        <source>Medical advisor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="518"/>
        <source>Webmaster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="524"/>
        <source>Build on %1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="525"/>
        <source>Build version : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="526"/>
        <source>Full application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="527"/>
        <source>SVN application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="528"/>
        <source>Build in debug mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="529"/>
        <source>Build in release mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="532"/>
        <source>Header</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="533"/>
        <source>Footer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="534"/>
        <source>Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="535"/>
        <source>Printing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="538"/>
        <source>Agenda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="539"/>
        <source>Agenda event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="540"/>
        <source>Agenda events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="542"/>
        <source>No availability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="543"/>
        <source>Attendee</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="544"/>
        <source>Attendees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="545"/>
        <source>User delegate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="546"/>
        <source>Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="547"/>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="548"/>
        <source>Tomorrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="549"/>
        <source>Yesterday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="550"/>
        <source>Current week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="551"/>
        <source>Next week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="552"/>
        <source>Previous week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="553"/>
        <source>Current month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="554"/>
        <source>Next month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="555"/>
        <source>Previous month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="558"/>
        <source>Arrived</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="559"/>
        <source>Cancelled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="560"/>
        <source>Missed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="561"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="562"/>
        <source>Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="563"/>
        <source>Approved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="566"/>
        <source>Zip archive (*.zip)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="567"/>
        <source>HTML files (*.htm *.html)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="568"/>
        <source>XML files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="569"/>
        <source>Text files (*.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="570"/>
        <source>Rich text files (*.rtf)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="571"/>
        <source>OpenOffice document (*.odt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="572"/>
        <source>All files(*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="578"/>
        <source>France</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="579"/>
        <source>Germany</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="580"/>
        <source>Canada</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="583"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="584"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="585"/>
        <source>Patient Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="586"/>
        <source>Patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="587"/>
        <source>Patients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="589"/>
        <source>Patient database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="590"/>
        <source>Clear patient&apos;s information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="591"/>
        <source>Toggle patient&apos;s information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="594"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="595"/>
        <source>Adress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="596"/>
        <source>Male</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="597"/>
        <source>Female</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="598"/>
        <source>Hermaphrodism</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="601"/>
        <source>Mister</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="602"/>
        <source>Miss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="603"/>
        <source>Madam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="604"/>
        <source>Doctor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="605"/>
        <source>Professor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="606"/>
        <source>Captain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="607"/>
        <source>Nurse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="608"/>
        <source>Secretary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="609"/>
        <source>Caregiver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="610"/>
        <source>Medical student</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="611"/>
        <source>Software administrator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="615"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="627"/>
        <source>Ctrl+L</source>
        <extracomment>Text Align Left shortcut key
----------
Text Align Left shortcut key : Mac specific</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="618"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="630"/>
        <source>Ctrl+R</source>
        <extracomment>Text Align Right shortcut key
----------
Text Align Right shortcut key : Mac specific</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="621"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="633"/>
        <source>Ctrl+E</source>
        <extracomment>Text Align Center shortcut key
----------
Text Align Center shortcut key : Mac specific</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="624"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="636"/>
        <source>Ctrl+J</source>
        <extracomment>Text Align Justify shortcut key
----------
Text Align Justify shortcut key : Mac specific</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="639"/>
        <source>Ctrl+Shift+T</source>
        <extracomment>Add table Editor shortcut key</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="644"/>
        <source>Toggle toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="645"/>
        <source>Open in editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="646"/>
        <source>Save editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="647"/>
        <source>Rich Text Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="648"/>
        <source>Add current date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="649"/>
        <source>Add user name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="650"/>
        <source>Add patient name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="651"/>
        <source>Add text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="655"/>
        <source>Ctrl+Shift+P</source>
        <extracomment>ShortCut for &quot;Print prescription&quot;</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="660"/>
        <source>All languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="661"/>
        <source>All other languages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
